@@ -362,7 +362,7 @@ def deploy(local, package_name, folder_path, port, quick_deploy):
             dfRunningContainers = dfAllContainers[dfAllContainers['State'] == 'running']
         else:
             delete_package(base_url, package_name)
-            loader1.stop()
+            loader1.quit()
             deploy(local, package_name, folder_path, port, quick_deploy)
             return
         # Check if container exists/running/stopped
@@ -442,84 +442,63 @@ def deploy(local, package_name, folder_path, port, quick_deploy):
 
 
 def undeploy(local, package_name, all):
-    if local:
-        base_url = get_roe_url()
-        # base_url returns none when roe api isn't running locally
-
-        # if all isn't specified and a package_name is given
-        if not all and package_name:
-            # List of Docker containers deployed
-            response_containers = requests.get(base_url + '/containers/?include_stopped=true')
-            dfAllContainers = pd.read_json(response_containers.text, orient='records')
-
-            # List of packages in the roe-packages volume
-            response_packages = requests.get(base_url + '/packages/')
-            dfPackages = pd.read_json(response_packages.text, orient='records')
-
-            # Check if there's nothing
-            if dfAllContainers.empty and dfPackages.empty:
-                raise NoRunningPackagesError()
-            # Ensures we don't get DataFrame errors
-            elif not dfAllContainers.empty:
-                if package_name in dfAllContainers.Names.values:
-                    checkDelete = input("Would you like to stop and delete the package? Enter Y to confirm: ").lower()
-                    if checkDelete == 'y':
-                        delete_both(base_url, package_name)
-                        click.echo(f"'{package_name}' package undeployed.")
-                        return
-                    else:
-                        click.echo(f"'{package_name}' is still running.")
-            # Checks for orphaned packages
-            if package_name in dfPackages.Name.values:
-                delete_package(base_url, package_name)
-                click.echo(f"'{package_name}' package undeployed.")
-            # Package must not exist in this case
-            else:
-                raise PackageExistenceError(package_name)
-
-        # all is an optional flag that requests to  delete all packages
-        elif all:
-            checkUndeploy = input(
-                "Are you sure you want to undeploy all packages? (This cannot be undone.) Enter Y to confirm: ").lower()
-            if checkUndeploy == 'y':
-                response_containers = requests.get(base_url + '/containers/?include_stopped=true')
-                dfAllContainers = pd.read_json(response_containers.text, orient='records')
-                if not dfAllContainers.empty:
-                    response_stop_all = requests.get(base_url + '/containers/stop/all/')
-
-                    if response_stop_all.status_code == 200:
-                        pass
-                    else:
-                        click.echo("Unable to stop all packages.")
-
-                    response_kill_all = requests.get(base_url + '/containers/kill/all/')
-
-                    if response_kill_all.status_code == 200:
-                        pass
-                    else:
-                        click.echo("Unable to kill all packages.")
-
-                    response_packages = requests.get(base_url + '/packages/')
-                    dfPackages = pd.read_json(response_packages.text, orient='records')
-                    package_list = dfPackages['Name'].tolist()
-                    for package_name in package_list:
-                        if package_name in dfAllContainers.Names.values:
-                            delete_container(base_url, package_name)
-                            click.echo("Undeployed '" + package_name + "' package.")
-
-                response_packages_prune = requests.get(base_url + '/packages/prune/')
-
-                if response_packages_prune.status_code == 200:
-                    click.echo("All packages undeployed.")
-                else:
-                    click.echo("Unable to delete all packages")
-            else:
-                click.echo("Undeploy all aborted.")
-        else:
-            raise MissingPackageInputError()
-    else:
+    if not local:
         raise NoLocalFlagError()
 
+    base_url = get_roe_url()
+    # base_url returns none when roe api isn't running locally
+
+    # if all isn't specified and a package_name is given
+    if not all and package_name:
+        # List of Docker containers deployed
+        response_containers = requests.get(base_url + '/containers/?include_stopped=true')
+        dfAllContainers = pd.read_json(response_containers.text, orient='records')
+
+        # List of packages in the roe-packages volume
+        response_packages = requests.get(base_url + '/packages/')
+        dfPackages = pd.read_json(response_packages.text, orient='records')
+
+        # Check if there's nothing
+        if dfAllContainers.empty and dfPackages.empty:
+            raise NoRunningPackagesError()
+        # Ensures we don't get DataFrame errors
+        elif not dfAllContainers.empty:
+            if package_name in dfAllContainers.Names.values:
+                checkDelete = input("Would you like to stop and delete the package? Enter Y to confirm: ").lower()
+                if checkDelete == 'y':
+                    delete_both(base_url, package_name)
+                    click.echo(f"'{package_name}' package undeployed.")
+                    return
+                else:
+                    click.echo(f"'{package_name}' is still running.")
+        # Checks for orphaned packages
+        if package_name in dfPackages.Name.values:
+            delete_package(base_url, package_name)
+            click.echo(f"'{package_name}' package undeployed.")
+        # Package must not exist in this case
+        else:
+            raise PackageExistenceError(package_name)
+
+    # all is an optional flag that requests to  delete all packages
+    elif all:
+        checkUndeploy = input(
+            "Are you sure you want to undeploy all packages? (This cannot be undone.) Enter Y to confirm: ").lower()
+        if checkUndeploy == 'y':
+            response_containers_prune = requests.get(base_url + "/containers/remove/all")
+            response_packages_prune = requests.get(base_url + '/packages/prune/')
+
+            if response_packages_prune.status_code == 200 and response_containers_prune.status_code == 200:
+                click.echo("Removed the following packages:")
+                # Remove quote marks and show all packages removed
+                click.echo(response_containers_prune.text[1:-1])
+
+            else:
+                click.echo("Unable to delete all packages")
+        else:
+            click.echo("Undeploy all aborted.")
+    else:
+        raise MissingPackageInputError()
+
     return
 
 
